"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RBTMenuBar = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const react_bootstrap_1 = require("react-bootstrap");
const react_bootstrap_icons_1 = require("react-bootstrap-icons");
const export_to_csv_fix_source_map_1 = require("export-to-csv-fix-source-map");
const search_1 = require("../search");
/**
 * This component builds a menu bar, this includes the Search box, spacing and download table as a csv.
 *
 * @param {RBTMenuBarOptions} props
 */
const RBTMenuBar = (props) => {
    const displayCompactBtn = (0, react_1.useMemo)(() => props.enableDensityToggle ?? true, [props.enableDensityToggle]);
    const displayExportBtn = (0, react_1.useMemo)(() => props.enableExportButton ?? true, [props.enableExportButton]);
    const styleVarient = (0, react_1.useMemo)(() => props.varient ?? 'dark', [props.varient]);
    const tableName = (0, react_1.useMemo)(() => {
        let result = 'SearchBar';
        if (props.name) {
            if (props.name.length > 0) {
                result = props.name + ' ' + result;
            }
        }
        return result;
    }, [props.name]);
    /**
     * Called by the download button, this will capture the information in the table and
     * return is a CSV for download by the user.
     */
    const performExport = () => {
        const data = props.data.map((value) => value.data);
        let exportName = 'Unknown' + '_' + Date.now();
        if (props.name) {
            if (props.name.length > 0) {
                exportName = props.name + '_' + Date.now();
            }
        }
        // Define rules for exporting.
        const csvExport = new export_to_csv_fix_source_map_1.ExportToCsv({
            showLabels: true,
            filename: exportName,
            useKeysAsHeaders: true,
        });
        csvExport.generateCsv(data);
    };
    return (react_1.default.createElement(react_1.default.Fragment, null, displayCompactBtn || displayExportBtn ? (react_1.default.createElement(react_bootstrap_1.Row, null,
        react_1.default.createElement(react_bootstrap_1.Col, null),
        react_1.default.createElement(react_bootstrap_1.Col, { md: 'auto' },
            react_1.default.createElement(react_bootstrap_1.InputGroup, null,
                react_1.default.createElement(search_1.RBTSearch, { ...props }),
                displayCompactBtn ? (react_1.default.createElement(react_bootstrap_1.Button, { variant: styleVarient, "aria-label": tableName + ' Compact Setting Toggle', onClick: () => {
                        if (props.setCompact) {
                            props.setCompact(!props.isCompact);
                        }
                    } }, props.isCompact ? react_1.default.createElement(react_bootstrap_icons_1.Grid3x3Gap, null) : react_1.default.createElement(react_bootstrap_icons_1.Grid3x2Gap, null))) : null,
                displayExportBtn ? (react_1.default.createElement(react_bootstrap_1.Button, { variant: styleVarient, "aria-label": tableName + ' Download CSV Button', tabIndex: 0, onClick: () => performExport() },
                    react_1.default.createElement(react_bootstrap_icons_1.Download, null))) : null)))) : null));
};
exports.RBTMenuBar = RBTMenuBar;
//# sourceMappingURL=menubar.components.js.map