"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const globals_1 = require("@jest/globals");
const rowcontrols_helper_1 = require("./rowcontrols.helper");
const testData = [
    { position: 0, filters: [], data: { firstName: 'Joe', surname: 'Bloggs', age: 24 } },
    { position: 1, filters: [], data: { firstName: 'Jane', surname: 'Doe', age: 36 } },
    { position: 2, filters: [], data: { firstName: 'John', surname: 'Smith', age: 48 } },
    { position: 3, filters: [], data: { firstName: 'Patty', surname: "O'Furniture", age: 24 } },
    { position: 4, filters: [], data: { firstName: 'Teri', surname: 'Dactyl', age: 36 } },
    { position: 5, filters: [], data: { firstName: 'Allie', surname: 'Grater', age: 48 } },
];
(0, globals_1.describe)('getRowOptions', () => {
    (0, globals_1.test)('Happy Path', () => {
        (0, globals_1.expect)((0, rowcontrols_helper_1.getRowOptions)(250)).toStrictEqual(['5', '10', '25', '50', '100', 'All']);
    });
    (0, globals_1.test)('Less Than 100', () => {
        (0, globals_1.expect)((0, rowcontrols_helper_1.getRowOptions)(75)).toStrictEqual(['5', '10', '25', '50', 'All']);
    });
    (0, globals_1.test)('Less Than 50', () => {
        (0, globals_1.expect)((0, rowcontrols_helper_1.getRowOptions)(30)).toStrictEqual(['5', '10', '25', 'All']);
    });
    (0, globals_1.test)('Less Than 25', () => {
        (0, globals_1.expect)((0, rowcontrols_helper_1.getRowOptions)(20)).toStrictEqual(['5', '10', 'All']);
    });
    (0, globals_1.test)('Less Than 10', () => {
        (0, globals_1.expect)((0, rowcontrols_helper_1.getRowOptions)(7)).toStrictEqual(['5', 'All']);
    });
    (0, globals_1.test)('Less Than 5', () => {
        (0, globals_1.expect)((0, rowcontrols_helper_1.getRowOptions)(3)).toStrictEqual(['All']);
    });
    (0, globals_1.test)('Negative', () => {
        (0, globals_1.expect)((0, rowcontrols_helper_1.getRowOptions)(-10)).toStrictEqual(['All']);
    });
});
(0, globals_1.describe)('getRowRangeText', () => {
    (0, globals_1.test)('Happy Path', () => {
        (0, globals_1.expect)((0, rowcontrols_helper_1.getRowRangeText)(100, 10, 0)).toBe('1 - 10 of 100');
    });
    (0, globals_1.test)('Invalid Rows', () => {
        (0, globals_1.expect)((0, rowcontrols_helper_1.getRowRangeText)(-123, 10, 0)).toBe('0 of 0');
    });
    (0, globals_1.test)('Invalid Rows on Page', () => {
        (0, globals_1.expect)((0, rowcontrols_helper_1.getRowRangeText)(100, -10, 0)).toBe('1 - ? of 100');
    });
    (0, globals_1.test)('Invalid Position', () => {
        (0, globals_1.expect)((0, rowcontrols_helper_1.getRowRangeText)(100, 10, 200)).toBe('? of 100');
    });
});
(0, globals_1.describe)('SetPaginationFilter', () => {
    (0, globals_1.test)('Empty Request', () => {
        const result = [];
        (0, globals_1.expect)((0, rowcontrols_helper_1.SetPaginationFilter)(0, 0, result)).toStrictEqual(result);
    });
    (0, globals_1.test)('Valid 2 Page', () => {
        const expected = [
            { position: 0, filters: [rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Joe', surname: 'Bloggs', age: 24 } },
            { position: 1, filters: [rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Jane', surname: 'Doe', age: 36 } },
            { position: 2, filters: [], data: { firstName: 'John', surname: 'Smith', age: 48 } },
            { position: 3, filters: [], data: { firstName: 'Patty', surname: "O'Furniture", age: 24 } },
            { position: 4, filters: [rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Teri', surname: 'Dactyl', age: 36 } },
            { position: 5, filters: [rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Allie', surname: 'Grater', age: 48 } },
        ];
        (0, globals_1.expect)((0, rowcontrols_helper_1.SetPaginationFilter)(2, 2, testData)).toStrictEqual(expected);
    });
    /**
     * We want to display 2 results, we give a position but data in that position has filters applied
     * this means we want the function to find 2 records which don't have alternate filters and display them.
     */
    (0, globals_1.test)('Valid support for alternate filters', () => {
        const testFilter = 'COMPLEX';
        const source = [
            { position: 0, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Joe', surname: 'Bloggs', age: 24 } },
            { position: 1, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Jane', surname: 'Doe', age: 36 } },
            { position: 2, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'John', surname: 'Smith', age: 48 } },
            { position: 3, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Patty', surname: "O'Furn", age: 24 } },
            { position: 4, filters: [rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Teri', surname: 'Dactyl', age: 36 } },
            { position: 5, filters: [rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Allie', surname: 'Grater', age: 48 } },
        ];
        const expected = [
            { position: 0, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Joe', surname: 'Bloggs', age: 24 } },
            { position: 1, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Jane', surname: 'Doe', age: 36 } },
            { position: 2, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'John', surname: 'Smith', age: 48 } },
            { position: 3, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Patty', surname: "O'Furn", age: 24 } },
            { position: 4, filters: [], data: { firstName: 'Teri', surname: 'Dactyl', age: 36 } },
            { position: 5, filters: [], data: { firstName: 'Allie', surname: 'Grater', age: 48 } },
        ];
        (0, globals_1.expect)((0, rowcontrols_helper_1.SetPaginationFilter)(2, 2, source)).toStrictEqual(expected);
    });
    (0, globals_1.test)('Test Nothing displayed', () => {
        const testFilter = 'COMPLEX';
        const source = [
            { position: 0, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Joe', surname: 'Bloggs', age: 24 } },
            { position: 1, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Jane', surname: 'Doe', age: 36 } },
            { position: 2, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'John', surname: 'Smith', age: 48 } },
            { position: 3, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Patty', surname: "O'Furn", age: 24 } },
            { position: 4, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Teri', surname: 'Dactyl', age: 36 } },
            { position: 5, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Allie', surname: 'Grater', age: 48 } },
        ];
        const expected = [
            { position: 0, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Joe', surname: 'Bloggs', age: 24 } },
            { position: 1, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Jane', surname: 'Doe', age: 36 } },
            { position: 2, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'John', surname: 'Smith', age: 48 } },
            { position: 3, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Patty', surname: "O'Furn", age: 24 } },
            { position: 4, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Teri', surname: 'Dactyl', age: 36 } },
            { position: 5, filters: [testFilter, rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Allie', surname: 'Grater', age: 48 } },
        ];
        (0, globals_1.expect)((0, rowcontrols_helper_1.SetPaginationFilter)(2, 2, source)).toStrictEqual(expected);
    });
    (0, globals_1.test)('Test Nothing displayed', () => {
        const testFilter = 'COMPLEX';
        const source = [
            { position: 0, filters: [], data: { firstName: 'Joe', surname: 'Bloggs', age: 24 } },
            { position: 1, filters: [], data: { firstName: 'Jane', surname: 'Doe', age: 36 } },
            { position: 2, filters: [], data: { firstName: 'John', surname: 'Smith', age: 48 } },
            { position: 3, filters: [], data: { firstName: 'Patty', surname: "O'Furn", age: 24 } },
            { position: 4, filters: [], data: { firstName: 'Teri', surname: 'Dactyl', age: 36 } },
            { position: 5, filters: [], data: { firstName: 'Allie', surname: 'Grater', age: 48 } },
        ];
        const expected = [
            { position: 0, filters: [rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Joe', surname: 'Bloggs', age: 24 } },
            { position: 1, filters: [rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Jane', surname: 'Doe', age: 36 } },
            { position: 2, filters: [], data: { firstName: 'John', surname: 'Smith', age: 48 } },
            { position: 3, filters: [], data: { firstName: 'Patty', surname: "O'Furn", age: 24 } },
            { position: 4, filters: [rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Teri', surname: 'Dactyl', age: 36 } },
            { position: 5, filters: [rowcontrols_helper_1.FILTER_VALUE], data: { firstName: 'Allie', surname: 'Grater', age: 48 } },
        ];
        (0, globals_1.expect)((0, rowcontrols_helper_1.SetPaginationFilter)(2, 2, source)).toStrictEqual(expected);
    });
});
//# sourceMappingURL=rowcontrols.test.js.map