"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RBTSearch = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const react_bootstrap_1 = require("react-bootstrap");
const react_bootstrap_icons_1 = require("react-bootstrap-icons");
const search_helpers_1 = require("./search.helpers");
/**
 * This is used to provide a search bar which will look through the supplied data objects and mark them as
 * filtered/not filtered dependning on search criteria provided.
 *
 * @component
 * @param {RBTSearchOptions} param0 this is used
 */
const RBTSearch = ({ columns, data, name, handleDisplayedRows, }) => {
    const tableName = (0, react_1.useMemo)(() => {
        let result = 'Search Bar';
        if (name) {
            if (name.length > 0) {
                result = name + ' ' + result;
            }
        }
        return result;
    }, [name]);
    /**
     * Columns must be marked as searchable, for the search bar to include them in analysis.
     */
    const searchableColumns = (0, react_1.useMemo)(() => {
        const keys = [];
        columns?.forEach((value) => {
            if (value.searchable && value.accessorKey) {
                keys.push(value.accessorKey.toString());
            }
        });
        return keys;
    }, [columns]);
    /**
     * If there are any columns which are searchable, this will be set to true.
     * This value is used to decide if the search bar should be shown.
     */
    const isSearchableTable = (0, react_1.useMemo)(() => {
        return searchableColumns && searchableColumns.length > 0 && typeof handleDisplayedRows !== 'undefined';
    }, [searchableColumns, handleDisplayedRows]);
    /**
     * This function will iterate over the data with the current search value looking for matches.
     * It will then set the displayed rows callback with the matching results.
     * @param {string} toFind the value to search the stored data for.
     */
    const handleSearchValue = (0, react_1.useCallback)((toFind) => {
        if (handleDisplayedRows) {
            // Convert to Upper case to remove case specific issues
            const upperToFind = toFind.toUpperCase();
            const results = (0, search_helpers_1.updateFilterAndDisplayed)(upperToFind, data, searchableColumns);
            handleDisplayedRows(results);
        }
    }, [columns, data]);
    return (react_1.default.createElement(react_1.default.Fragment, null, isSearchableTable ? (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(react_bootstrap_1.Form.Control, { placeholder: 'Search', "aria-label": tableName + ' Search Input', tabIndex: 0, onChange: (e) => handleSearchValue(e.target.value) }),
        react_1.default.createElement(react_bootstrap_1.InputGroup.Text, null,
            react_1.default.createElement(react_bootstrap_icons_1.Search, null)))) : null));
};
exports.RBTSearch = RBTSearch;
//# sourceMappingURL=search.components.js.map