"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isMatch = exports.updateFilterAndDisplayed = exports.FILTER_VALUE = void 0;
const common_1 = require("../common");
/** Unique value for filters applied by this component. */
exports.FILTER_VALUE = 'search';
const updateFilterAndDisplayed = (toFind, rows, searchableColumns) => {
    const results = [];
    //iterate over each table record to find ones which match our search term
    rows?.forEach((row) => {
        // If the filtering status of the row has changed we need to capture this and feed
        // it back to the other components.
        if ((0, exports.isMatch)(toFind, row, searchableColumns)) {
            row.filters = (0, common_1.RemoveFilterFromArray)(exports.FILTER_VALUE, row.filters);
        }
        else if (row.filters.indexOf(exports.FILTER_VALUE) < 0) {
            row.filters.push(exports.FILTER_VALUE);
        }
        results.push(row);
    });
    // if we haven't changed what is displayed update nothing!
    return results;
};
exports.updateFilterAndDisplayed = updateFilterAndDisplayed;
/**
 * Supplies a value and a table row. This will check the defined fields within the table to
 * see if they match the value. If they do it will return true.
 *
 * @param toFind the term to find within the data
 * @param row the row containing the data object we need to check
 * @param searchableColumns the fields in the data object we should compare
 * @returns true if toFind is empty
 */
const isMatch = (toFind, row, searchableColumns) => {
    // if toFind is cleared then we assume nothing is filtered.
    let match = toFind.length == 0;
    const data = row.data;
    if (data) {
        const toFindUpper = toFind.toUpperCase();
        searchableColumns.forEach((key) => {
            // TODO This needs to be configured for multi level objects
            const value = data[key];
            if (typeof value === 'string') {
                match = match || value.toUpperCase().indexOf(toFindUpper) > -1;
            }
        });
    }
    return match;
};
exports.isMatch = isMatch;
//# sourceMappingURL=search.helpers.js.map