"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const globals_1 = require("@jest/globals");
const search_helpers_1 = require("./search.helpers");
const testData = [
    { position: 0, filters: [], data: { firstName: 'Joe', surname: 'Bloggs', age: 24 } },
    { position: 0, filters: [], data: { firstName: 'Jane', surname: 'Doe', age: 36 } },
    { position: 0, filters: [], data: { firstName: 'John', surname: 'Smith', age: 48 } },
    { position: 0, filters: [], data: { firstName: 'Patty', surname: "O'Furniture", age: 24 } },
    { position: 0, filters: [], data: { firstName: 'Teri', surname: 'Dactyl', age: 36 } },
    { position: 0, filters: [], data: { firstName: 'Allie', surname: 'Grater', age: 48 } },
];
(0, globals_1.describe)('isMatch', () => {
    (0, globals_1.test)('Empty Filter', () => {
        const result = [];
        (0, globals_1.expect)((0, search_helpers_1.isMatch)('', testData[0], [])).toStrictEqual(true);
    });
    (0, globals_1.test)('No Match', () => {
        const result = [];
        (0, globals_1.expect)((0, search_helpers_1.isMatch)('blah', testData[0], ['firstName'])).toStrictEqual(false);
    });
    (0, globals_1.test)('Valid Match', () => {
        const result = [];
        (0, globals_1.expect)((0, search_helpers_1.isMatch)('Joe', testData[0], ['firstName', 'surname', 'age'])).toStrictEqual(true);
    });
    (0, globals_1.test)('Valid Term, Wrong fields', () => {
        const result = [];
        (0, globals_1.expect)((0, search_helpers_1.isMatch)('Joe', testData[0], ['surname', 'age'])).toStrictEqual(false);
    });
});
(0, globals_1.describe)('updateFilterAndDisplayed', () => {
    (0, globals_1.test)('Empty Request', () => {
        const result = [];
        (0, globals_1.expect)((0, search_helpers_1.updateFilterAndDisplayed)('', [], [])).toStrictEqual(result);
    });
    (0, globals_1.test)('Valid 2 Page', () => {
        const supplied = [
            { position: 0, filters: [], data: { firstName: 'Joe', surname: 'Bloggs', age: 24 } },
            { position: 1, filters: [], data: { firstName: 'Jane', surname: 'Doe', age: 36 } },
            { position: 2, filters: [], data: { firstName: 'John', surname: 'Smith', age: 48 } },
            { position: 3, filters: [], data: { firstName: 'Patty', surname: "O'Furniture", age: 24 } },
            { position: 4, filters: [search_helpers_1.FILTER_VALUE], data: { firstName: 'Teri', surname: 'Dactyl', age: 36 } },
            { position: 5, filters: [search_helpers_1.FILTER_VALUE], data: { firstName: 'Allie', surname: 'Grater', age: 48 } },
        ];
        const expected = [
            { position: 0, filters: [], data: { firstName: 'Joe', surname: 'Bloggs', age: 24 } },
            { position: 1, filters: [search_helpers_1.FILTER_VALUE], data: { firstName: 'Jane', surname: 'Doe', age: 36 } },
            { position: 2, filters: [search_helpers_1.FILTER_VALUE], data: { firstName: 'John', surname: 'Smith', age: 48 } },
            { position: 3, filters: [search_helpers_1.FILTER_VALUE], data: { firstName: 'Patty', surname: "O'Furniture", age: 24 } },
            { position: 4, filters: [search_helpers_1.FILTER_VALUE], data: { firstName: 'Teri', surname: 'Dactyl', age: 36 } },
            { position: 5, filters: [search_helpers_1.FILTER_VALUE], data: { firstName: 'Allie', surname: 'Grater', age: 48 } },
        ];
        (0, globals_1.expect)((0, search_helpers_1.updateFilterAndDisplayed)('joe', supplied, ['firstName'])).toStrictEqual(expected);
    });
});
//# sourceMappingURL=search.test.js.map