"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RBTable = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const react_bootstrap_1 = require("react-bootstrap");
const menubar_1 = require("../menubar");
const rowcontrols_1 = require("../rowcontrols");
const common_1 = require("../common");
const tableHead_1 = require("../tableHead");
const tablePlaceholder_1 = require("../tablePlaceholder");
const tableBody_components_1 = require("../tableBody/tableBody.components");
const RBTable = ({ columns, data, name, varient, header, footer, }) => {
    //
    const initialisedRows = (0, react_1.useMemo)(() => {
        const results = [];
        //
        if (data) {
            for (let index = 0; index < data.length; index++) {
                const row = {
                    data: data[index],
                    position: index,
                    filters: [],
                };
                results.push(row);
            }
        }
        // Ensure all the results are correctly sorted
        return results.sort(common_1.CompareRBTRow);
    }, [data]);
    const showTableHead = (0, react_1.useMemo)(() => header?.enableTableHead ?? true, [header]);
    // We want to wrap eac data item within a row object which controls how informaiton is displayed
    // by default nothing should be filtered from view and everything should be displayed.
    const [rows, setRows] = (0, react_1.useState)(initialisedRows);
    const [columnDefs] = (0, react_1.useState)(columns ?? []);
    const [compact, setCompact] = (0, react_1.useState)(false);
    const styleVarient = (0, react_1.useMemo)(() => varient ?? 'dark', [varient]);
    const tableName = (0, react_1.useMemo)(() => {
        let result = 'Table';
        if (name && name.length > 0) {
            result = name + ' Table';
        }
        return result;
    }, [name]);
    return (react_1.default.createElement(react_bootstrap_1.Container, { fluid: true },
        react_1.default.createElement(menubar_1.RBTMenuBar, { enableDensityToggle: header?.enableDensityToggle ?? showTableHead, enableExportButton: header?.enableExportButton ?? showTableHead, isCompact: compact, setCompact: setCompact, name: name, varient: styleVarient, columns: columnDefs, data: rows, handleDisplayedRows: setRows }),
        react_1.default.createElement(react_bootstrap_1.Row, null,
            react_1.default.createElement(react_bootstrap_1.Col, null,
                react_1.default.createElement(react_bootstrap_1.Table, { hover: true, responsive: true, size: compact ? 'sm' : '', "aria-label": tableName },
                    react_1.default.createElement(tableHead_1.RBTableHead, { columns: columnDefs, enableTableHead: showTableHead, name: name, varient: styleVarient }),
                    rows.length > 0 ? (react_1.default.createElement(tableBody_components_1.RBTableBody, { columns: columnDefs, name: name, varient: styleVarient, data: rows })) : (react_1.default.createElement(tablePlaceholder_1.RBTablePlaceholder, { columns: columnDefs, name: name, varient: styleVarient }))))),
        (footer?.enablePagination ?? true) ? (react_1.default.createElement(rowcontrols_1.RBTRowControls, { columns: columnDefs, data: rows, handleDisplayedRows: setRows, name: name, varient: styleVarient })) : null));
};
exports.RBTable = RBTable;
//# sourceMappingURL=table.components.js.map