"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RBTableBody = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const common_1 = require("../common");
const RBTableBody = ({ columns, data, name, }) => {
    const columnPrefix = (0, react_1.useMemo)(() => (name && name.length > 0 ? name + '.table.body' : 'table.body'), [name]);
    const displayed = (0, react_1.useMemo)(() => {
        const results = data.filter((record) => record.filters.length === 0);
        return results.sort(common_1.CompareRBTRow);
    }, [data]);
    /**
     * This will process the Cell atribute (if set)
     * @param column
     * @param row
     * @returns
     */
    const GenerateCell = (index, column, row) => {
        let id = columnPrefix;
        if (column.id && column.id.length > 0) {
            id = column.id;
        }
        let result;
        if (typeof column.Cell === 'function') {
            result = (react_1.default.createElement("td", { key: id + '.' + row.position + '.' + index }, column.Cell({ column: id, originalRow: row.data })));
        }
        // If there was no Id or Cell then result should be undefined
        if (!result && typeof column.accessorFn === 'function') {
            const keyOrValue = column.accessorFn(row.data);
            if (keyOrValue in row.data) {
                const data = row.data[keyOrValue];
                if (typeof data === 'string' || typeof data === 'number') {
                    result = react_1.default.createElement("td", { key: id + '.' + row.position + '.' + index }, data);
                }
            }
            else if (typeof keyOrValue === 'string' || typeof keyOrValue === 'number') {
                result = react_1.default.createElement("td", { key: id + '.' + row.position + '.' + index }, keyOrValue);
            }
            else {
                console.log('GenerateAccessorFN - Unable to convert data into table AccessorFN: ' + JSON.stringify(keyOrValue));
            }
        }
        // If there was no Id or AccessorFN then result should be undefined
        if (!result && column.accessorKey) {
            const data = row.data[column.accessorKey];
            if (typeof data === 'string' || typeof data === 'number') {
                result = react_1.default.createElement("td", { key: id + '.' + row.position + '.' + index }, data);
            }
            else {
                console.log('GenerateAccessorFN - Unable to convert data into table AccessorFN: ' + JSON.stringify(data));
            }
        }
        return result;
    };
    return (react_1.default.createElement("tbody", null, displayed.map((row) => {
        return (react_1.default.createElement("tr", { key: row.position }, columns.map((column, index) => {
            return GenerateCell(index, column, row);
        })));
    })));
};
exports.RBTableBody = RBTableBody;
//# sourceMappingURL=tableBody.components.js.map