import { RBTRow } from '../common';
/** Unique value for filters applied by this component. */
export declare const FILTER_VALUE = "rowcontrols";
/**
 * Used to work out the set ranges that should be displayed in the row controls based
 * on the supplied number.
 * @param rows the rows contained within the table (e.g. length of data array)
 * @returns a valid string array with row values.
 */
export declare const getRowOptions: (rows: number) => string[];
/**
 * Used to create a text block to explain what rows are currently displayed on the page.
 *
 * @param rows the total rows of data within the table
 * @param rowsPerPage how many rows of data the table is currently displayed
 * @param position the current start position of the display
 * @returns a valid text string.
 */
export declare const getRowRangeText: (rows: number, rowsPerPage: number, position: number) => string;
/**
 * Various components in the library can cause a Table row to be filtered from the display (e.g. search).
 * The pagination filter is supposed to display blocks of results.
 *
 * This means it needs to move to the target position and look for rows which only have the pagination
 * filter applied and remove the pagination filter under the desired number of page objects is visible.
 *
 *
 * @param position the position we should be centered on.
 * @param rowsPerPage  the number of rows we want to see on a 'page'
 * @param rows  the rows to be processed
 * @param rowsToMark allows us to control how much is displayed
 * @returns processed RBTRows
 */
export declare const SetPaginationFilter: <TData extends Record<string, unknown>>(position: number, rowsPerPage: number, rows: RBTRow<TData>[], rowsToMark?: number) => RBTRow<TData>[];
//# sourceMappingURL=rowcontrols.helper.d.ts.map